==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/shipping/dpd.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	dpd.lang.inc.php 2018-02-16
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2018 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_SHIPPING_DPD_ALLOWED_DESC' => 'Geben Sie <b>einzeln</b> die Zonen an, in welche ein Versand möglich sein soll. (z.B. AT,DE (lassen Sie dieses Feld leer, wenn Sie alle Zonen erlauben wollen))',
	'MODULE_SHIPPING_DPD_ALLOWED_TITLE' => 'Erlaubte Versandzonen',
	'MODULE_SHIPPING_DPD_COST_10_DESC' => 'Versandkosten nach Zone 10 Bestimmungsorte, basierend auf einer Gruppe von max. Bestellgewichten. Beispiel: 3:8.50,7:10.50,... Gewicht von kleiner oder gleich 3 würde 8.50 für die Zone 1 Bestimmungsländer kosten.',
	'MODULE_SHIPPING_DPD_COST_10_TITLE' => 'Zone 10 Versandkosten',
	'MODULE_SHIPPING_DPD_COST_1_DESC' => 'Versandkosten nach Zone 1 Bestimmungsorte, basierend auf einer Gruppe von max. Bestellgewichten. Beispiel: 3:8.50,7:10.50,... Gewicht von kleiner oder gleich 3 würde 8.50 für die Zone 1 Bestimmungsländer kosten.',
	'MODULE_SHIPPING_DPD_COST_1_TITLE' => 'Zone 1 Versandkosten',
	'MODULE_SHIPPING_DPD_COST_2_DESC' => 'Versandkosten nach Zone 2 Bestimmungsorte, basierend auf einer Gruppe von max. Bestellgewichten. Beispiel: 3:8.50,7:10.50,... Gewicht von kleiner oder gleich 3 würde 8.50 für die Zone 1 Bestimmungsländer kosten.',
	'MODULE_SHIPPING_DPD_COST_2_TITLE' => 'Zone 2 Versandkosten',
	'MODULE_SHIPPING_DPD_COST_3_DESC' => 'Versandkosten nach Zone 3 Bestimmungsorte, basierend auf einer Gruppe von max. Bestellgewichten. Beispiel: 3:8.50,7:10.50,... Gewicht von kleiner oder gleich 3 würde 8.50 für die Zone 1 Bestimmungsländer kosten.',
	'MODULE_SHIPPING_DPD_COST_3_TITLE' => 'Zone 3 Versandkosten',
	'MODULE_SHIPPING_DPD_COST_4_DESC' => 'Versandkosten nach Zone 4 Bestimmungsorte, basierend auf einer Gruppe von max. Bestellgewichten. Beispiel: 3:8.50,7:10.50,... Gewicht von kleiner oder gleich 3 würde 8.50 für die Zone 1 Bestimmungsländer kosten.',
	'MODULE_SHIPPING_DPD_COST_4_TITLE' => 'Zone 4 Versandkosten',
	'MODULE_SHIPPING_DPD_COST_5_DESC' => 'Versandkosten nach Zone 5 Bestimmungsorte, basierend auf einer Gruppe von max. Bestellgewichten. Beispiel: 3:8.50,7:10.50,... Gewicht von kleiner oder gleich 3 würde 8.50 für die Zone 1 Bestimmungsländer kosten.',
	'MODULE_SHIPPING_DPD_COST_5_TITLE' => 'Zone 5 Versandkosten',
	'MODULE_SHIPPING_DPD_COST_6_DESC' => 'Versandkosten nach Zone 6 Bestimmungsorte, basierend auf einer Gruppe von max. Bestellgewichten. Beispiel: 3:8.50,7:10.50,... Gewicht von kleiner oder gleich 3 würde 8.50 für die Zone 1 Bestimmungsländer kosten.',
	'MODULE_SHIPPING_DPD_COST_6_TITLE' => 'Zone 6 Versandkosten',
	'MODULE_SHIPPING_DPD_COST_7_DESC' => 'Versandkosten nach Zone 7 Bestimmungsorte, basierend auf einer Gruppe von max. Bestellgewichten. Beispiel: 3:8.50,7:10.50,... Gewicht von kleiner oder gleich 3 würde 8.50 für die Zone 1 Bestimmungsländer kosten.',
	'MODULE_SHIPPING_DPD_COST_7_TITLE' => 'Zone 7 Versandkosten',
	'MODULE_SHIPPING_DPD_COST_8_DESC' => 'Versandkosten nach Zone 8 Bestimmungsorte, basierend auf einer Gruppe von max. Bestellgewichten. Beispiel: 3:8.50,7:10.50,... Gewicht von kleiner oder gleich 3 würde 8.50 für die Zone 1 Bestimmungsländer kosten.',
	'MODULE_SHIPPING_DPD_COST_8_TITLE' => 'Zone 8 Versandkosten',
	'MODULE_SHIPPING_DPD_COST_9_DESC' => 'Versandkosten nach Zone 9 Bestimmungsorte, basierend auf einer Gruppe von max. Bestellgewichten. Beispiel: 3:8.50,7:10.50,... Gewicht von kleiner oder gleich 3 würde 8.50 für die Zone 1 Bestimmungsländer kosten.',
	'MODULE_SHIPPING_DPD_COST_9_TITLE' => 'Zone 9 Versandkosten',
	'MODULE_SHIPPING_DPD_COUNTRIES_10_DESC' => 'Durch Komma getrennte Liste von ISO Ländercodes (2 Zeichen), welche Teil von Zone 10 sind.',
	'MODULE_SHIPPING_DPD_COUNTRIES_10_TITLE' => 'Zone 10 Länder',
	'MODULE_SHIPPING_DPD_COUNTRIES_1_DESC' => 'Durch Komma getrennte Liste von ISO Ländercodes (2 Zeichen), welche Teil von Zone 1 sind.',
	'MODULE_SHIPPING_DPD_COUNTRIES_1_TITLE' => 'Zone 1 Länder',
	'MODULE_SHIPPING_DPD_COUNTRIES_2_DESC' => 'Durch Komma getrennte Liste von ISO Ländercodes (2 Zeichen), welche Teil von Zone 2 sind.',
	'MODULE_SHIPPING_DPD_COUNTRIES_2_TITLE' => 'Zone 2 Länder',
	'MODULE_SHIPPING_DPD_COUNTRIES_3_DESC' => 'Durch Komma getrennte Liste von ISO Ländercodes (2 Zeichen), welche Teil von Zone 3 sind.',
	'MODULE_SHIPPING_DPD_COUNTRIES_3_TITLE' => 'Zone 3 Länder',
	'MODULE_SHIPPING_DPD_COUNTRIES_4_DESC' => 'Durch Komma getrennte Liste von ISO Ländercodes (2 Zeichen), welche Teil von Zone 4 sind.',
	'MODULE_SHIPPING_DPD_COUNTRIES_4_TITLE' => 'Zone 4 Länder',
	'MODULE_SHIPPING_DPD_COUNTRIES_5_DESC' => 'Durch Komma getrennte Liste von ISO Ländercodes (2 Zeichen), welche Teil von Zone 5 sind.',
	'MODULE_SHIPPING_DPD_COUNTRIES_5_TITLE' => 'Zone 5 Länder',
	'MODULE_SHIPPING_DPD_COUNTRIES_6_DESC' => 'Durch Komma getrennte Liste von ISO Ländercodes (2 Zeichen), welche Teil von Zone 6 sind.',
	'MODULE_SHIPPING_DPD_COUNTRIES_6_TITLE' => 'Zone 6 Länder',
	'MODULE_SHIPPING_DPD_COUNTRIES_7_DESC' => 'Durch Komma getrennte Liste von ISO Ländercodes (2 Zeichen), welche Teil von Zone 7 sind.',
	'MODULE_SHIPPING_DPD_COUNTRIES_7_TITLE' => 'Zone 7 Länder',
	'MODULE_SHIPPING_DPD_COUNTRIES_8_DESC' => 'Durch Komma getrennte Liste von ISO Ländercodes (2 Zeichen), welche Teil von Zone 8 sind.',
	'MODULE_SHIPPING_DPD_COUNTRIES_8_TITLE' => 'Zone 8 Länder',
	'MODULE_SHIPPING_DPD_COUNTRIES_9_DESC' => 'Durch Komma getrennte Liste von ISO Ländercodes (2 Zeichen), welche Teil von Zone 9 sind.',
	'MODULE_SHIPPING_DPD_COUNTRIES_9_TITLE' => 'Zone 9 Länder',
	'MODULE_SHIPPING_DPD_HANDLING_10_DESC' => 'Handling Gebühr für diese Versandzone',
	'MODULE_SHIPPING_DPD_HANDLING_10_TITLE' => 'Zone 10 Handling Gebühr',
	'MODULE_SHIPPING_DPD_HANDLING_1_DESC' => 'Handling Gebühr für diese Versandzone',
	'MODULE_SHIPPING_DPD_HANDLING_1_TITLE' => 'Zone 1 Handling Gebühr',
	'MODULE_SHIPPING_DPD_HANDLING_2_DESC' => 'Handling Gebühr für diese Versandzone',
	'MODULE_SHIPPING_DPD_HANDLING_2_TITLE' => 'Zone 2 Handling Gebühr',
	'MODULE_SHIPPING_DPD_HANDLING_3_DESC' => 'Handling Gebühr für diese Versandzone',
	'MODULE_SHIPPING_DPD_HANDLING_3_TITLE' => 'Zone 3 Handling Gebühr',
	'MODULE_SHIPPING_DPD_HANDLING_4_DESC' => 'Handling Gebühr für diese Versandzone',
	'MODULE_SHIPPING_DPD_HANDLING_4_TITLE' => 'Zone 4 Handling Gebühr',
	'MODULE_SHIPPING_DPD_HANDLING_5_DESC' => 'Handling Gebühr für diese Versandzone',
	'MODULE_SHIPPING_DPD_HANDLING_5_TITLE' => 'Zone 5 Handling Gebühr',
	'MODULE_SHIPPING_DPD_HANDLING_6_DESC' => 'Handling Gebühr für diese Versandzone',
	'MODULE_SHIPPING_DPD_HANDLING_6_TITLE' => 'Zone 6 Handling Gebühr',
	'MODULE_SHIPPING_DPD_HANDLING_7_DESC' => 'Handling Gebühr für diese Versandzone',
	'MODULE_SHIPPING_DPD_HANDLING_7_TITLE' => 'Zone 7 Handling Gebühr',
	'MODULE_SHIPPING_DPD_HANDLING_8_DESC' => 'Handling Gebühr für diese Versandzone',
	'MODULE_SHIPPING_DPD_HANDLING_8_TITLE' => 'Zone 8 Handling Gebühr',
	'MODULE_SHIPPING_DPD_HANDLING_9_DESC' => 'Handling Gebühr für diese Versandzone',
	'MODULE_SHIPPING_DPD_HANDLING_9_TITLE' => 'Zone 9 Handling Gebühr',
	'MODULE_SHIPPING_DPD_INVALID_ZONE' => 'Diese Option steht für ihre Lieferadresse nicht zur Verfügung',
	'MODULE_SHIPPING_DPD_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige',
	'MODULE_SHIPPING_DPD_SORT_ORDER_TITLE' => 'Sortierreihenfolge',
	'MODULE_SHIPPING_DPD_STATUS_DESC' => 'Möchten Sie Versandkosten nach Zonen anbieten?',
	'MODULE_SHIPPING_DPD_STATUS_TITLE' => 'Versandkosten nach Zonen Methode aktivieren',
	'MODULE_SHIPPING_DPD_TAX_CLASS_DESC' => 'Folgende Steuerklasse an Versandkosten anwenden',
	'MODULE_SHIPPING_DPD_TAX_CLASS_TITLE' => 'Steuerklasse',
	'MODULE_SHIPPING_DPD_TEXT_DESCRIPTION' => 'Versandkosten Zonenbasierend',
	'MODULE_SHIPPING_DPD_TEXT_TITLE' => 'DPD',
	'MODULE_SHIPPING_DPD_TEXT_UNITS' => 'kg',
	'MODULE_SHIPPING_DPD_TEXT_WAY' => 'Versand nach:',
	'MODULE_SHIPPING_DPD_UNDEFINED_RATE' => 'Unversicherter Versand nicht möglich. Bitte andere Versandart wählen.'
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/modules/shipping/dpd.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	dpd.lang.inc.php 2018-02-16
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2018 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_SHIPPING_DPD_ALLOWED_DESC' => 'Gib <b>einzeln</b> die Zonen an, in welche ein Versand möglich sein soll. (z.B. AT,DE (lasse dieses Feld leer, wenn du alle Zonen erlauben willst))',
	'MODULE_SHIPPING_DPD_ALLOWED_TITLE' => 'Erlaubte Versandzonen',
	'MODULE_SHIPPING_DPD_COST_10_DESC' => 'Versandkosten nach Zone 10 Bestimmungsorte, basierend auf einer Gruppe von max. Bestellgewichten. Beispiel: 3:8.50,7:10.50,... Gewicht von kleiner oder gleich 3 würde 8.50 für die Zone 1 Bestimmungsländer kosten.',
	'MODULE_SHIPPING_DPD_COST_10_TITLE' => 'Zone 10 Versandkosten',
	'MODULE_SHIPPING_DPD_COST_1_DESC' => 'Versandkosten nach Zone 1 Bestimmungsorte, basierend auf einer Gruppe von max. Bestellgewichten. Beispiel: 3:8.50,7:10.50,... Gewicht von kleiner oder gleich 3 würde 8.50 für die Zone 1 Bestimmungsländer kosten.',
	'MODULE_SHIPPING_DPD_COST_1_TITLE' => 'Zone 1 Versandkosten',
	'MODULE_SHIPPING_DPD_COST_2_DESC' => 'Versandkosten nach Zone 2 Bestimmungsorte, basierend auf einer Gruppe von max. Bestellgewichten. Beispiel: 3:8.50,7:10.50,... Gewicht von kleiner oder gleich 3 würde 8.50 für die Zone 1 Bestimmungsländer kosten.',
	'MODULE_SHIPPING_DPD_COST_2_TITLE' => 'Zone 2 Versandkosten',
	'MODULE_SHIPPING_DPD_COST_3_DESC' => 'Versandkosten nach Zone 3 Bestimmungsorte, basierend auf einer Gruppe von max. Bestellgewichten. Beispiel: 3:8.50,7:10.50,... Gewicht von kleiner oder gleich 3 würde 8.50 für die Zone 1 Bestimmungsländer kosten.',
	'MODULE_SHIPPING_DPD_COST_3_TITLE' => 'Zone 3 Versandkosten',
	'MODULE_SHIPPING_DPD_COST_4_DESC' => 'Versandkosten nach Zone 4 Bestimmungsorte, basierend auf einer Gruppe von max. Bestellgewichten. Beispiel: 3:8.50,7:10.50,... Gewicht von kleiner oder gleich 3 würde 8.50 für die Zone 1 Bestimmungsländer kosten.',
	'MODULE_SHIPPING_DPD_COST_4_TITLE' => 'Zone 4 Versandkosten',
	'MODULE_SHIPPING_DPD_COST_5_DESC' => 'Versandkosten nach Zone 5 Bestimmungsorte, basierend auf einer Gruppe von max. Bestellgewichten. Beispiel: 3:8.50,7:10.50,... Gewicht von kleiner oder gleich 3 würde 8.50 für die Zone 1 Bestimmungsländer kosten.',
	'MODULE_SHIPPING_DPD_COST_5_TITLE' => 'Zone 5 Versandkosten',
	'MODULE_SHIPPING_DPD_COST_6_DESC' => 'Versandkosten nach Zone 6 Bestimmungsorte, basierend auf einer Gruppe von max. Bestellgewichten. Beispiel: 3:8.50,7:10.50,... Gewicht von kleiner oder gleich 3 würde 8.50 für die Zone 1 Bestimmungsländer kosten.',
	'MODULE_SHIPPING_DPD_COST_6_TITLE' => 'Zone 6 Versandkosten',
	'MODULE_SHIPPING_DPD_COST_7_DESC' => 'Versandkosten nach Zone 7 Bestimmungsorte, basierend auf einer Gruppe von max. Bestellgewichten. Beispiel: 3:8.50,7:10.50,... Gewicht von kleiner oder gleich 3 würde 8.50 für die Zone 1 Bestimmungsländer kosten.',
	'MODULE_SHIPPING_DPD_COST_7_TITLE' => 'Zone 7 Versandkosten',
	'MODULE_SHIPPING_DPD_COST_8_DESC' => 'Versandkosten nach Zone 8 Bestimmungsorte, basierend auf einer Gruppe von max. Bestellgewichten. Beispiel: 3:8.50,7:10.50,... Gewicht von kleiner oder gleich 3 würde 8.50 für die Zone 1 Bestimmungsländer kosten.',
	'MODULE_SHIPPING_DPD_COST_8_TITLE' => 'Zone 8 Versandkosten',
	'MODULE_SHIPPING_DPD_COST_9_DESC' => 'Versandkosten nach Zone 9 Bestimmungsorte, basierend auf einer Gruppe von max. Bestellgewichten. Beispiel: 3:8.50,7:10.50,... Gewicht von kleiner oder gleich 3 würde 8.50 für die Zone 1 Bestimmungsländer kosten.',
	'MODULE_SHIPPING_DPD_COST_9_TITLE' => 'Zone 9 Versandkosten',
	'MODULE_SHIPPING_DPD_COUNTRIES_10_DESC' => 'Durch Komma getrennte Liste von ISO Ländercodes (2 Zeichen), welche Teil von Zone 10 sind.',
	'MODULE_SHIPPING_DPD_COUNTRIES_10_TITLE' => 'Zone 10 Länder',
	'MODULE_SHIPPING_DPD_COUNTRIES_1_DESC' => 'Durch Komma getrennte Liste von ISO Ländercodes (2 Zeichen), welche Teil von Zone 1 sind.',
	'MODULE_SHIPPING_DPD_COUNTRIES_1_TITLE' => 'Zone 1 Länder',
	'MODULE_SHIPPING_DPD_COUNTRIES_2_DESC' => 'Durch Komma getrennte Liste von ISO Ländercodes (2 Zeichen), welche Teil von Zone 2 sind.',
	'MODULE_SHIPPING_DPD_COUNTRIES_2_TITLE' => 'Zone 2 Länder',
	'MODULE_SHIPPING_DPD_COUNTRIES_3_DESC' => 'Durch Komma getrennte Liste von ISO Ländercodes (2 Zeichen), welche Teil von Zone 3 sind.',
	'MODULE_SHIPPING_DPD_COUNTRIES_3_TITLE' => 'Zone 3 Länder',
	'MODULE_SHIPPING_DPD_COUNTRIES_4_DESC' => 'Durch Komma getrennte Liste von ISO Ländercodes (2 Zeichen), welche Teil von Zone 4 sind.',
	'MODULE_SHIPPING_DPD_COUNTRIES_4_TITLE' => 'Zone 4 Länder',
	'MODULE_SHIPPING_DPD_COUNTRIES_5_DESC' => 'Durch Komma getrennte Liste von ISO Ländercodes (2 Zeichen), welche Teil von Zone 5 sind.',
	'MODULE_SHIPPING_DPD_COUNTRIES_5_TITLE' => 'Zone 5 Länder',
	'MODULE_SHIPPING_DPD_COUNTRIES_6_DESC' => 'Durch Komma getrennte Liste von ISO Ländercodes (2 Zeichen), welche Teil von Zone 6 sind.',
	'MODULE_SHIPPING_DPD_COUNTRIES_6_TITLE' => 'Zone 6 Länder',
	'MODULE_SHIPPING_DPD_COUNTRIES_7_DESC' => 'Durch Komma getrennte Liste von ISO Ländercodes (2 Zeichen), welche Teil von Zone 7 sind.',
	'MODULE_SHIPPING_DPD_COUNTRIES_7_TITLE' => 'Zone 7 Länder',
	'MODULE_SHIPPING_DPD_COUNTRIES_8_DESC' => 'Durch Komma getrennte Liste von ISO Ländercodes (2 Zeichen), welche Teil von Zone 8 sind.',
	'MODULE_SHIPPING_DPD_COUNTRIES_8_TITLE' => 'Zone 8 Länder',
	'MODULE_SHIPPING_DPD_COUNTRIES_9_DESC' => 'Durch Komma getrennte Liste von ISO Ländercodes (2 Zeichen), welche Teil von Zone 9 sind.',
	'MODULE_SHIPPING_DPD_COUNTRIES_9_TITLE' => 'Zone 9 Länder',
	'MODULE_SHIPPING_DPD_HANDLING_10_DESC' => 'Handling Gebühr für diese Versandzone',
	'MODULE_SHIPPING_DPD_HANDLING_10_TITLE' => 'Zone 10 Handling Gebühr',
	'MODULE_SHIPPING_DPD_HANDLING_1_DESC' => 'Handling Gebühr für diese Versandzone',
	'MODULE_SHIPPING_DPD_HANDLING_1_TITLE' => 'Zone 1 Handling Gebühr',
	'MODULE_SHIPPING_DPD_HANDLING_2_DESC' => 'Handling Gebühr für diese Versandzone',
	'MODULE_SHIPPING_DPD_HANDLING_2_TITLE' => 'Zone 2 Handling Gebühr',
	'MODULE_SHIPPING_DPD_HANDLING_3_DESC' => 'Handling Gebühr für diese Versandzone',
	'MODULE_SHIPPING_DPD_HANDLING_3_TITLE' => 'Zone 3 Handling Gebühr',
	'MODULE_SHIPPING_DPD_HANDLING_4_DESC' => 'Handling Gebühr für diese Versandzone',
	'MODULE_SHIPPING_DPD_HANDLING_4_TITLE' => 'Zone 4 Handling Gebühr',
	'MODULE_SHIPPING_DPD_HANDLING_5_DESC' => 'Handling Gebühr für diese Versandzone',
	'MODULE_SHIPPING_DPD_HANDLING_5_TITLE' => 'Zone 5 Handling Gebühr',
	'MODULE_SHIPPING_DPD_HANDLING_6_DESC' => 'Handling Gebühr für diese Versandzone',
	'MODULE_SHIPPING_DPD_HANDLING_6_TITLE' => 'Zone 6 Handling Gebühr',
	'MODULE_SHIPPING_DPD_HANDLING_7_DESC' => 'Handling Gebühr für diese Versandzone',
	'MODULE_SHIPPING_DPD_HANDLING_7_TITLE' => 'Zone 7 Handling Gebühr',
	'MODULE_SHIPPING_DPD_HANDLING_8_DESC' => 'Handling Gebühr für diese Versandzone',
	'MODULE_SHIPPING_DPD_HANDLING_8_TITLE' => 'Zone 8 Handling Gebühr',
	'MODULE_SHIPPING_DPD_HANDLING_9_DESC' => 'Handling Gebühr für diese Versandzone',
	'MODULE_SHIPPING_DPD_HANDLING_9_TITLE' => 'Zone 9 Handling Gebühr',
	'MODULE_SHIPPING_DPD_INVALID_ZONE' => 'Diese Option steht für ihre Lieferadresse nicht zur Verfügung',
	'MODULE_SHIPPING_DPD_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige',
	'MODULE_SHIPPING_DPD_SORT_ORDER_TITLE' => 'Sortierreihenfolge',
	'MODULE_SHIPPING_DPD_STATUS_DESC' => 'Möchtest du Versandkosten nach Zonen anbieten?',
	'MODULE_SHIPPING_DPD_STATUS_TITLE' => 'Versandkosten nach Zonen Methode aktivieren',
	'MODULE_SHIPPING_DPD_TAX_CLASS_DESC' => 'Folgende Steuerklasse an Versandkosten anwenden',
	'MODULE_SHIPPING_DPD_TAX_CLASS_TITLE' => 'Steuerklasse',
	'MODULE_SHIPPING_DPD_TEXT_DESCRIPTION' => 'Versandkosten Zonenbasierend',
	'MODULE_SHIPPING_DPD_TEXT_TITLE' => 'DPD',
	'MODULE_SHIPPING_DPD_TEXT_UNITS' => 'kg',
	'MODULE_SHIPPING_DPD_TEXT_WAY' => 'Versand nach:',
	'MODULE_SHIPPING_DPD_UNDEFINED_RATE' => 'Unversicherter Versand nicht möglich. Bitte andere Versandart wählen.'
);
